@@ -21,7 +21,7 @@
 NamespacePtr FileNamespace;
 
 void
-import_File_namespace()
+import_File_namespace(void)
 {
     ENTER ();
     static const struct fbuiltin_0 funcs_0[] = {
@@ -210,7 +210,7 @@ import_File_namespace()
 	    "\n"
 	    " Raised when reading at end-of-file.\n"
 	    " 'file' is the file at eof.\n" },
-	{0,			0 },
+	{0, 0, 0, 0 },
     };
 
     const struct ebuiltin   *e;
